@@ -16,102 +16,103 @@
  */
 package org.apache.commons.pool2;
 
+import java.util.Objects;
+
 /**
- * A base implementation of <code>KeyedPooledObjectFactory</code>.
+ * A base implementation of {@code KeyedPooledObjectFactory}.
  * <p>
  * All operations defined here are essentially no-op's.
  * </p>
+ * <p>
  * This class is immutable, and therefore thread-safe.
+ * </p>
  *
  * @see KeyedPooledObjectFactory
- *
  * @param <K> The type of keys managed by this factory.
  * @param <V> Type of element managed by this factory.
- *
- * @version $Revision: 1333925 $
- *
  * @since 2.0
  */
-public abstract class BaseKeyedPooledObjectFactory<K,V>
-        implements KeyedPooledObjectFactory<K,V> {
+public abstract class BaseKeyedPooledObjectFactory<K, V> extends BaseObject implements KeyedPooledObjectFactory<K, V> {
 
     /**
-     * Create an instance that can be served by the pool.
+     * Reinitializes an instance to be returned by the pool.
+     * <p>
+     * The default implementation is a no-op.
+     * </p>
      *
-     * @param key the key used when constructing the object
-     * @return an instance that can be served by the pool
-     *
-     * @throws Exception if there is a problem creating a new instance,
-     *    this will be propagated to the code requesting an object.
+     * @param key the key used when selecting the object
+     * @param p a {@code PooledObject} wrapping the instance to be activated
      */
-    public abstract V create(K key)
-        throws Exception;
-
-    /**
-     * Wrap the provided instance with an implementation of
-     * {@link PooledObject}.
-     *
-     * @param value the instance to wrap
-     *
-     * @return The provided instance, wrapped by a {@link PooledObject}
-     */
-    public abstract PooledObject<V> wrap(V value);
-
     @Override
-    public PooledObject<V> makeObject(K key) throws Exception {
-        return wrap(create(key));
+    public void activateObject(final K key, final PooledObject<V> p) throws Exception {
+        // The default implementation is a no-op.
     }
 
     /**
-     * Destroy an instance no longer needed by the pool.
+     * Creates an instance that can be served by the pool.
+     *
+     * @param key the key used when constructing the object
+     * @return an instance that can be served by the pool
+     * @throws Exception if there is a problem creating a new instance,
+     *    this will be propagated to the code requesting an object.
+     */
+    public abstract V create(K key) throws Exception;
+
+    /**
+     * Destroys an instance no longer needed by the pool.
      * <p>
      * The default implementation is a no-op.
+     * </p>
      *
      * @param key the key used when selecting the instance
-     * @param p a {@code PooledObject} wrapping the the instance to be destroyed
+     * @param p a {@code PooledObject} wrapping the instance to be destroyed
      */
     @Override
-    public void destroyObject(K key, PooledObject<V> p)
-        throws Exception {
+    public void destroyObject(final K key, final PooledObject<V> p) throws Exception {
+        // The default implementation is a no-op.
+    }
+
+    @Override
+    public PooledObject<V> makeObject(final K key) throws Exception {
+        return wrap(
+                Objects.requireNonNull(create(key), () -> String.format("BaseKeyedPooledObjectFactory(%s).create(key=%s) = null", getClass().getName(), key)));
+    }
+
+    /**
+     * Uninitializes an instance to be returned to the idle object pool.
+     * <p>
+     * The default implementation is a no-op.
+     * </p>
+     *
+     * @param key the key used when selecting the object
+     * @param p a {@code PooledObject} wrapping the instance to be passivated
+     */
+    @Override
+    public void passivateObject(final K key, final PooledObject<V> p) throws Exception {
+        // The default implementation is a no-op.
     }
 
     /**
      * Ensures that the instance is safe to be returned by the pool.
      * <p>
      * The default implementation always returns {@code true}.
+     * </p>
      *
      * @param key the key used when selecting the object
-     * @param p a {@code PooledObject} wrapping the the instance to be validated
-     * @return always <code>true</code> in the default implementation
+     * @param p a {@code PooledObject} wrapping the instance to be validated
+     * @return always {@code true} in this default implementation
      */
     @Override
-    public boolean validateObject(K key, PooledObject<V> p) {
+    public boolean validateObject(final K key, final PooledObject<V> p) {
         return true;
     }
 
     /**
-     * Reinitialize an instance to be returned by the pool.
-     * <p>
-     * The default implementation is a no-op.
+     * Wraps the provided instance with an implementation of
+     * {@link PooledObject}.
      *
-     * @param key the key used when selecting the object
-     * @param p a {@code PooledObject} wrapping the the instance to be activated
+     * @param value the instance to wrap, should not be null.
+     * @return The provided instance, wrapped by a {@link PooledObject}
      */
-    @Override
-    public void activateObject(K key, PooledObject<V> p)
-        throws Exception {
-    }
-
-    /**
-     * Uninitialize an instance to be returned to the idle object pool.
-     * <p>
-     * The default implementation is a no-op.
-     *
-     * @param key the key used when selecting the object
-     * @param p a {@code PooledObject} wrapping the the instance to be passivated
-     */
-    @Override
-    public void passivateObject(K key, PooledObject<V> p)
-        throws Exception {
-    }
-}
\ No newline at end of file
+    public abstract PooledObject<V> wrap(V value);
+}
